@@ -6,6 +6,7 @@
 @license: GNU GPL
 """
 import evolution
+import gtk
 	
 class ContactHandler:
 	
@@ -45,7 +46,21 @@ class ContactHandler:
 		#l = [x.get_name() for x in res]
 		#print "search for:", pname, "gave res: ", l
 		if res != None:
-			return res[0].get_photo(imgsize)
+			img = res[0].get_photo(imgsize)
+			if img == None:
+				vcardlist = res[0].get_vcard_string().replace('\r', '').split('\n') # vcard for first result
+				for line in vcardlist:
+					if line.startswith("PHOTO;VALUE=uri:file://"):
+						imgstr = line.replace("PHOTO;VALUE=uri:file://", "")
+						img = gtk.gdk.pixbuf_new_from_file(imgstr)
+						height = img.get_height()
+						if height != imgsize:
+							newheight = imgsize
+							newwidth = int(newheight * img.get_width() / height)
+							#print "h:", height, "w:", img.get_width()
+							#print "newh:", newheight, "neww:", newwidth
+							img = img.scale_simple(newwidth, newheight, gtk.gdk.INTERP_BILINEAR)
+			return img
 		else:
 			return None
 		
@@ -56,8 +71,13 @@ if __name__ == '__main__':
 	
 	#print cb.get_name_from_number('+46')
 	
-	#r = ab.search('name') # Returns List of results
-	#print r
-	#l = [x.get_name() for x in r] # list of results
-	#u = r[0].get_name() # name of the first result
-	#print r[0].get_vcard_string() # vcard for first result
+	"""r = cb.ab.search('') # Returns List of results
+	print r
+	l = [x.get_name() for x in r] # list of results
+	u = r[0].get_name() # name of the first result
+	vcardlist = r[0].get_vcard_string().replace('\r', '').split('\n') # vcard for first result
+	for line in vcardlist:
+		if line.startswith("PHOTO;VALUE=uri:file://"):
+			print line.replace("PHOTO;VALUE=uri:file://", "")
+			
+	#print r[0].get_photo(64)"""
