@@ -25,6 +25,7 @@ class fMMS_GUI(hildon.Program):
 		self._mmsdir = self.config.get_mmsdir()
 		self._pushdir = self.config.get_pushdir()
 		self.ch = ContactH.ContactHandler()
+		self.osso_c = osso.Context("fMMS", "0.1.0", False)
 	
 		if not os.path.isdir(self._mmsdir):
 			print "creating dir", self._mmsdir
@@ -97,7 +98,6 @@ class fMMS_GUI(hildon.Program):
 		
 		if self.config.get_firstlaunch() == 1:
 			print "firstlaunch"
-			self.osso_c = osso.Context("fMMS", "0.1.0", False)
 			note = osso.SystemNote(self.osso_c)
 			firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\nAlso, only implemented attachment is image."
 			note.system_note_dialog(firstlaunchmessage , 'notice')
@@ -337,7 +337,7 @@ class fMMS_GUI(hildon.Program):
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.SystemNoteInfoprint ("fMMS: Opening message")
-		
+		### end ugly workaround ###
 		
 		gobject.timeout_add(100, self.return_false)
 		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
@@ -384,8 +384,8 @@ class fMMS_GUI(hildon.Program):
 	
 		menu.show_all()
 		
-		return menu
-		
+		return menu		
+	
 	""" actions for mms menu """
 	def mms_menu_button_clicked(self, button, fname):
 		buttontext = button.get_label()
@@ -459,12 +459,19 @@ class fMMS_GUI(hildon.Program):
 		for fname in filelist:
 			(name, ext) = os.path.splitext(fname)
 			if ext == ".jpg" or ext == ".png":
-				#pixbuf = gtk.gdk.pixbuf_new_from_file(path + "/" + fname)
-				#textbuffer.insert_pixbuf(textbuffer.get_end_iter(), pixbuf)
+			
+				""" insert the image in an eventbox so we can get signals """
+				ebox = gtk.EventBox()
 				img = gtk.Image()
 				img.set_from_file(path + "/" + fname)
-				#img.show()
-				container.add(img)
+				fullpath = path + "/" + fname
+				ebox.add(img)
+				## TODO: make this menu proper without this ugly
+				# args passing
+				menu = self.mms_img_menu(fullpath)
+				ebox.tap_and_hold_setup(menu)
+				#ebox.connect('tap-and-hold', self.mms_img_clicked)
+				container.add(ebox)
 			elif ext == ".txt" or ext.startswith(".txt"):
 				fp = open(path + "/" + fname, 'r')
 				contents = fp.read()
@@ -474,6 +481,30 @@ class fMMS_GUI(hildon.Program):
 				
 		textview.set_buffer(textbuffer)
 		container.add(textview)
+		
+	""" action on click on image """
+	def mms_img_clicked(self, widget, data):
+		path = "file://" + data
+		#print path
+		rpc = osso.Rpc(self.osso_c)
+		rpc.rpc_run("com.nokia.image_viewer", "/com/nokia/image_viewer", "com.nokia.image_viewer", "mime_open", (str, path))
+		
+
+
+	""" long press on image creates this """
+	def mms_img_menu(self, data=None):
+		print "menu created"
+		menu = gtk.Menu()
+		menu.set_title("hildon-context-sensitive-menu")
+
+		openItem = gtk.MenuItem("Open")
+		menu.append(openItem)
+		openItem.connect("activate", self.mms_img_clicked, data)
+		openItem.show()
+		menu.show_all()
+		return menu
+
+	
 	
 	""" reads a saved push message into a dict """
 	def _read_push_as_list(self, fname):
