@@ -169,6 +169,7 @@ class fMMS_GUI(hildon.Program):
 		attachment = self.bAttachment.get_label()
 		if attachment == "Attachment" or attachment == None:
 			attachment = None
+			self.attachmentIsResized = False
 		else:
 			print attachment
 			filetype = mimetypes.guess_type(attachment)[0]
@@ -199,8 +200,7 @@ class fMMS_GUI(hildon.Program):
 			### TODO: Clean up and make this look decent
 			message = str(status) + "_" + str(reason)
 		
-			message = message.replace('\0','')
-			reply = str(output).replace('\0','')
+			reply = str(output)
 			#print message
 			#note = osso.SystemNote(self.osso_c)
 			#ret = note.system_note_dialog("MMSC REPLIED:" + message + "\nBODY:" + reply, 'notice')
